# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Security.SecurityChecker

Module implementing the security checker.

### Global Attributes

None

### Classes

SecurityChecker | Class implementing a checker for security issues.

### Functions

None

## SecurityChecker

Class implementing a checker for security issues.

### Derived from

None

### Class Attributes

Codes

### Class Methods

None

### Methods

SecurityChecker | Constructor
__ignoreCode | Private method to check if the message code should be ignored.
getConfig | Public method to get the configuration dictionary.
reportError | Public method to record an issue.
run | Public method to check the given source against security related conditions.

### Static Methods

None

#### SecurityChecker (Constructor)

SecurityChecker(source, filename, tree, select, ignore, expected, repeat, args)

Constructor

source (list of str)
  source code to be checked
filename (str)
  name of the source file
tree (ast.Module)
  AST tree of the source code
select (list of str)
  list of selected codes
ignore (list of str)
  list of codes to be ignored
expected (list of str)
  list of expected codes
repeat (bool)
  flag indicating to report each occurrence of a code
args (dict)
  dictionary of arguments for the security checks

#### SecurityChecker.__ignoreCode

__ignoreCode(code)

Private method to check if the message code should be ignored.

code (str)
  message code to check for

Return:
  flag indicating to ignore the given code

Return Type:
  bool

#### SecurityChecker.getConfig

getConfig()

Public method to get the configuration dictionary.

Return:
  dictionary containing the configuration

Return Type:
  dict

#### SecurityChecker.reportError

reportError(lineNumber, offset, code, severity, confidence, *args)

Public method to record an issue.

lineNumber (int)
  line number of the issue
offset (int)
  position within line of the issue
code (str)
  message code
severity (str)
  severity code (H = high, M = medium, L = low, U = undefined)
confidence (str)
  confidence code (H = high, M = medium, L = low, U = undefined)
args (list)
  arguments for the message

#### SecurityChecker.run

run()

Public method to check the given source against security related conditions.

Up